@@ -282,6 +282,41 @@ sub conflictHandlers {
   $t;
 }
 
+
+# produces the text mapping states to conflicthandlers
+sub stateConflict {
+  my $self = shift;
+
+  my $c = $self->{GRAMMAR}{CONFLICTHANDLERS};
+  my %stateConflict;
+
+  my %t = ();
+  for my $cn (keys %$c) {
+    my $ce = $c->{$cn};
+    my $codeh = $ce->{codeh};
+    $codeh = "sub { $codeh }";
+    my @s = defined($ce->{states}) ?  @{$ce->{states}} : ();
+    for my $s (@s) {
+        my ($sn) = keys %$s;
+        #my ($tokens) = values %$s;
+        #$tokens = join ',', @$tokens;
+        $t{$sn} = '' unless defined($t{$sn});
+        $t{$sn} .= << "NEWSTATECONFLICTENTRY";
+                   { 
+                      name => '$cn', 
+                      codeh => $codeh,
+                   },
+NEWSTATECONFLICTENTRY
+    } #for states
+  } #for  conflict names
+ 
+  my $t = '{ ';
+  for my $s (keys %t) {
+    $t .= "$s => [ $t{$s} ],";
+  }
+  $t .= ' }';
+}
+
 #####################################
 # Method To Return the Bypass Option#
 #####################################
